@@ -31,7 +31,7 @@ HEADER: str = "@"
 NAMES: str = "*"
 TYPES: str = "$"
 SEGMENTS: str = "#segment"
-SEGMENT_MARKER: str = ("start", "end")
+SEGMENT_MARKER: Tuple[str, str] = ("start", "end")
 COLX: str = "X"
 COLY: str = "Y"
 COLTURN: str = "TURN"
